@@ -756,7 +756,7 @@ sub write_all {
 sub _r500 {
     my($self, $message) = @_;
     $message = Carp::shortmess($message); # add lineno and filename
-    return(0, 500, 'Internal Server Error',
+    return(0, 500, "Internal Response: $message",
         ['Content-Length' => length($message)], $message);
 }
 
